pub struct Args {
pub verbosity: String,
/* private fields */
}Expand description
The Args struct is used to contain and parse command line arguments
-t –target
-v –verbosity <[none, low, high]> The level of program output
-n –threads
-p –port-range int:int,int,int The port range or comma separated ports to scan
-m –timeout
–probe When this is provided an HTTP GET request will be sent to the port
Do not use –probe when scanning untrusted hosts as they may send a malicious response
Fields
verbosity: StringThe verbosity level (none, low, high)