pub struct ScanResult { /* private fields */ }Expand description
A struct to contain scan results for a given port:
status will be set to open if a connection succeeds
If the –probe flag is used, banner will contain the first 1024 bytes
returned by the service on that port, if it supports HTTP